@@ -1,8 +1,8 @@
 /**
  * @fileOverview HTML5 canvas image functions
  * @author Ian Moore (imoore76 at yahoo dot com)
- * @version $Id: canvasimages.js 496 2012-11-02 13:04:44Z imooreyahoo@gmail.com $
- * @copyright Copyright (C) 2010-2012 Ian Moore (imoore76 at yahoo dot com)
+ * @version $Id: canvasimages.js 569 2013-10-17 16:57:52Z imoore76 $
+ * @copyright Copyright (C) 2010-2013 Ian Moore (imoore76 at yahoo dot com)
  */
 
 /**
@@ -22,90 +22,6 @@ var isCanvasSupported = function(){
 	return __vboxIsCanvasSupported;
 };
 
-/**
- * Draw arrow images when document is loaded
- */
-var vboxImageDownWhite = null;
-var vboxImageDownGrey = null;
-var vboxImageRightWhite = null;
-var vboxImageRightGrey = null;
-$(document).ready(function(){
-	
-	// Draw canvas images if supported
-	if(!isCanvasSupported())
-		return;
-
-	var createCanvas = function(color) {
-		
-		return $('<canvas />').attr({'width':'18','height':'18'}).each(function(idx,canvas){
-			
-			canvas.width = 18;
-			canvas.height = 18;
-			
-			var ctx = canvas.getContext('2d');
-			
-			ctx.strokeStyle = color;
-			ctx.lineWidth = 2;
-			ctx.lineCap = 'round';
-			
-			// Circle
-			ctx.arc(9,9,8,(Math.PI/180)*0,(Math.PI/180)*360,true);
-			ctx.stroke();
-			
-			// "V"
-			ctx.moveTo(6,6);
-			ctx.lineTo(9,12);
-			ctx.lineTo(12,6);
-			ctx.stroke();
-			ctx.save();
-			
-		})[0];
-		
-	};
-	vboxImageDownWhite = createCanvas('#FFFFFF');
-	vboxImageDownGrey = createCanvas('#999999');
-	
-	var createCanvas = function(color) {
-		
-		return $('<canvas />').attr({'width':'18','height':'18'}).each(function(idx,can){
-			
-			can.height = 18;
-			can.width = 18;
-			var ctx = can.getContext('2d');
-						
-			ctx.strokeStyle = color;
-			ctx.lineWidth = 2;
-			ctx.lineCap = 'round';
-			
-			iMargin = 1;
-			iconSize = 16;
-			width = 16;
-			height = 16;
-			
-            ctx.beginPath();
-            ctx.moveTo(iMargin,iMargin);
-            ctx.lineTo(iMargin + (width / 2), iMargin);
-            ctx.arc(iMargin + (width/2), iMargin + (height / 2), iconSize / 2, 1.5 * Math.PI, 0.5 * Math.PI, false);
-            ctx.lineTo(iMargin, iMargin + height);
-			ctx.closePath();
-			ctx.stroke();
-			
-			ctx.moveTo(iMargin + 5, iMargin + 5);
-			ctx.lineTo(iMargin + height - 5, iMargin + width / 2);
-			ctx.lineTo(iMargin + 5, iMargin + width - 5);
-            
-            ctx.stroke();
-            
-            ctx.save();
-		})[0];
-	};
-	
-	vboxImageRightWhite = createCanvas('#FFFFFF');
-	vboxImageRightGrey = createCanvas('#999999');
-
-		
-});
-
 var __vboxPreviewCanvasCache = [];
 function vboxDrawPreviewCanvas(can, imageObj, text, width, height) {
 	
@@ -164,47 +80,22 @@ function vboxDrawPreviewCanvas(can, imageObj, text, width, height) {
 		
 		cachedCtx.moveTo(margin*2,margin);
 		
-		// Opera's arcTo always seems to go counter clockwise
-		// and does not follow control specs
-		if($.browser.opera) {
-			
-			// Left line and top left
-			cachedCtx.arcTo(margin *2, margin, margin, margin*2, margin);
-			cachedCtx.lineTo(margin, height-(margin*2));
-			
-			// bottom and bottom left
-			cachedCtx.arcTo(margin, height-(margin*2), (margin*2), height-(margin), margin);
-			cachedCtx.lineTo(width-(margin*2), height-margin);
-			
-			// Side and bottom right
-			cachedCtx.arcTo(width-(margin*2), height-margin, width-margin, height-(margin*2), margin);
-			cachedCtx.lineTo(width-margin, margin*2);
-			
-			// top and top right
-			cachedCtx.arcTo(width-margin, margin*2, width-(margin*2),margin, margin);
-			cachedCtx.lineTo(margin*2, margin);
-			
-			
-		} else {
-			
-			// top and top right
-			cachedCtx.lineTo(width-(margin*2), margin);
-			cachedCtx.arcTo(width-margin, margin, width-margin,margin*2, margin);
-			
-			// Side and bottom right
-			cachedCtx.lineTo(width-margin, height-(margin*2));
-			cachedCtx.arcTo(width-margin, height-margin, width-(margin*2), height-margin, margin);
-			
-			// bottom and bottom left
-			cachedCtx.lineTo(margin*2, height-margin);
-			cachedCtx.arcTo(margin, height-margin, margin, height-(margin*2), margin);
-			
-			// Left line and top left
-			cachedCtx.lineTo(margin, margin*2);
-			cachedCtx.arcTo(margin, margin, margin * 2, margin, margin);
-			
-		}
+		// top and top right
+		cachedCtx.lineTo(width-(margin*2), margin);
+		cachedCtx.arcTo(width-margin, margin, width-margin,margin*2, margin);
 		
+		// Side and bottom right
+		cachedCtx.lineTo(width-margin, height-(margin*2));
+		cachedCtx.arcTo(width-margin, height-margin, width-(margin*2), height-margin, margin);
+		
+		// bottom and bottom left
+		cachedCtx.lineTo(margin*2, height-margin);
+		cachedCtx.arcTo(margin, height-margin, margin, height-(margin*2), margin);
+		
+		// Left line and top left
+		cachedCtx.lineTo(margin, margin*2);
+		cachedCtx.arcTo(margin, margin, margin * 2, margin, margin);
+			
 		cachedCtx.closePath();
 		cachedCtx.save();
 		cachedCtx.shadowOffsetX = 5;
@@ -236,41 +127,31 @@ function vboxDrawPreviewCanvas(can, imageObj, text, width, height) {
 		var cvs = document.createElement('canvas');
 
 		/* Gloss */
-		if($.browser.opera && $.browser.version.substring(0,2) < 12) {
-
-			// Opera before 12 does not get this right. Just
-			// leave a blank canvas
-			cvs.width = rectWidth;
-			cvs.height = rectHeight;
-
-		} else {
-			
-			var rectX = 0;
-			var rectY = 0;
-			var rectWidth = width-(margin+screenMargin)*2;
-			var rectHeight = height-(margin+screenMargin)*2;
-			
-			cvs.width = rectWidth;
-			cvs.height = rectHeight;
-			
-			var ctxBlur = cvs.getContext('2d');
-			ctxBlur.beginPath();
-			ctxBlur.lineWidth = 1;
-			ctxBlur.strokeStyle = "#000000";
-			ctxBlur.moveTo(rectX,rectY);
-			ctxBlur.lineTo(rectWidth, rectY);
-			ctxBlur.lineTo(rectWidth,rectHeight*1.0/3.0);
-			ctxBlur.bezierCurveTo(rectX+rectWidth / 2.0, rectY + rectHeight * 1.0/3.0,
-					rectX+rectWidth / 2.0, rectY + rectHeight * 2.0/3.0,
-					rectX, rectY + rectHeight * 2.0/3.0);
-			ctxBlur.closePath();
-			ctxBlur.fillStyle="rgba(255,255,255,0.3)";
-			ctxBlur.fill();
-			
-			stackBlurCanvasRGBA( cvs, 0, 0, rectWidth, rectHeight, 17 );
-			
-			ctx.drawImage(cvs, margin+screenMargin, margin+screenMargin, rectWidth, rectHeight);
-		}
+		var rectX = 0;
+		var rectY = 0;
+		var rectWidth = width-(margin+screenMargin)*2;
+		var rectHeight = height-(margin+screenMargin)*2;
+		
+		cvs.width = rectWidth;
+		cvs.height = rectHeight;
+		
+		var ctxBlur = cvs.getContext('2d');
+		ctxBlur.beginPath();
+		ctxBlur.lineWidth = 1;
+		ctxBlur.strokeStyle = "#000000";
+		ctxBlur.moveTo(rectX,rectY);
+		ctxBlur.lineTo(rectWidth, rectY);
+		ctxBlur.lineTo(rectWidth,rectHeight*1.0/3.0);
+		ctxBlur.bezierCurveTo(rectX+rectWidth / 2.0, rectY + rectHeight * 1.0/3.0,
+				rectX+rectWidth / 2.0, rectY + rectHeight * 2.0/3.0,
+				rectX, rectY + rectHeight * 2.0/3.0);
+		ctxBlur.closePath();
+		ctxBlur.fillStyle="rgba(255,255,255,0.3)";
+		ctxBlur.fill();
+		
+		stackBlurCanvasRGBA( cvs, 0, 0, rectWidth, rectHeight, 17 );
+		
+		ctx.drawImage(cvs, margin+screenMargin, margin+screenMargin, rectWidth, rectHeight);
 
 		__vboxPreviewCanvasCache[width+'x'+height] = {
 				'monitor' : cachedCanvas,
